#
# spec file for package augeas
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           augeas
Version:        0.7.4
Release:        1
Summary:        A library for changing configuration files
Group:          System/Libraries
License:        GPLv3+ ; LGPLv2.1+
Url:            http://augeas.net/
Source0:        http://augeas.net/download/augeas-%{version}.tar.bz2
Source1:        baselibs.conf
Patch0:         augeas-modprobe-lense.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  glib2-devel readline-devel

%description
A library for programmatically editing configuration files. Augeas
parses configuration files into a tree structure, which it exposes
through its public API. Changes made through the API are written back
to the initially read files.

The transformation works very hard to preserve comments and formatting
details. It is controlled by ``lens'' definitions that describe the
file format and the transformation into a tree.

%define __shrlibname lib%{name}0

%package        devel
License:        GPLv3+ ; LGPLv2.1+
Summary:        A library for changing configuration files
Group:          Development/Libraries/C and C++
Requires:       %{__shrlibname} = %{version}

%description    devel
A library for programmatically editing configuration files. Augeas
parses configuration files into a tree structure, which it exposes
through its public API. Changes made through the API are written back
to the initially read files.

The transformation works very hard to preserve comments and formatting
details. It is controlled by ``lens'' definitions that describe the
file format and the transformation into a tree.

%package        -n %{__shrlibname}


License:        GPLv3+ ; LGPLv2.1+
Summary:        A library for changing configuration files
Group:          Development/Libraries/C and C++
Recommends:     %{name}-lenses = %{version}

%description    -n %{__shrlibname}
A library for programmatically editing configuration files. Augeas
parses configuration files into a tree structure, which it exposes
through its public API. Changes made through the API are written back
to the initially read files.

The transformation works very hard to preserve comments and formatting
details. It is controlled by ``lens'' definitions that describe the
file format and the transformation into a tree.

%package        lenses
License:        GPLv3+ ; LGPLv2.1+
Summary:        Official set of lenses for use by %{__shrlibname}
Group:          Development/Libraries/Other
Requires:       %{__shrlibname} = %{version}

%description    lenses
Augeas parses configuration files described in lenses into a tree
structure, which it exposes through its public API. Lenses are the
building blocks of the file <-> tree transformation. The transformation
is controlled by ``lens'' definitions that describe the file format and
mapping of its contents into a tree. This package includes the official
set of lenses.

%package        lense-tests
License:        GPLv3+ ; LGPLv2.1+
Summary:        Set of tests for official Augeas lenses
Group:          Development/Libraries/Other
Requires:       %{name}-lenses = %{version}

%description    lense-tests
Set of tests for official Augeas lenses. These can be used when
modifying the official lenses, or when creating new ones.

%prep
%setup -q
%patch0 -p1

%build
export CFLAGS="-Wno-error $RPM_OPT_FLAGS"
%configure --disable-static --datadir=%{_datadir}/%{__shrlibname}
%{__make} %_smp_mflags

%install
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'
# create symlinks of augeas.vim files to vim/site
mkdir -p $RPM_BUILD_ROOT/usr/share/vim/site/ftdetect; \
mkdir $RPM_BUILD_ROOT/usr/share/vim/site/syntax; \
ln -s %{_datadir}/%{__shrlibname}/vim/vimfiles/ftdetect/augeas.vim \
      ${RPM_BUILD_ROOT}/usr/share/vim/site/ftdetect/augeas.vim
ln -s %{_datadir}/%{__shrlibname}/vim/vimfiles/syntax/augeas.vim \
      ${RPM_BUILD_ROOT}/usr/share/vim/site/syntax/augeas.vim

%clean
rm -rf $RPM_BUILD_ROOT

%post -n %{__shrlibname}
/sbin/ldconfig

%postun -n %{__shrlibname}
/sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/augtool
%{_bindir}/augparse
%{_bindir}/fadot
%{_mandir}/man1/*
%doc AUTHORS COPYING NEWS

%files -n %{__shrlibname}
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/augeas.pc

%files lenses
%defattr(-,root,root,-)
%dir %{_datadir}/%{__shrlibname}
%dir %{_datadir}/%{__shrlibname}/%{name}
%dir %{_datadir}/%{__shrlibname}/%{name}/lenses
%dir %{_datadir}/%{__shrlibname}/%{name}/lenses/dist
%{_datadir}/%{__shrlibname}/%{name}/lenses/dist/*.aug
%dir %{_datadir}/vim
%dir %{_datadir}/vim/site
%dir %{_datadir}/vim/site/ftdetect
%{_datadir}/vim/site/ftdetect/augeas.vim
%dir %{_datadir}/vim/site/syntax
%{_datadir}/vim/site/syntax/augeas.vim
%dir %{_datadir}/%{__shrlibname}/vim
%dir %{_datadir}/%{__shrlibname}/vim/vimfiles
%dir %{_datadir}/%{__shrlibname}/vim/vimfiles/ftdetect
%{_datadir}/%{__shrlibname}/vim/vimfiles/ftdetect/augeas.vim
%dir %{_datadir}/%{__shrlibname}/vim/vimfiles/syntax
%{_datadir}/%{__shrlibname}/vim/vimfiles/syntax/augeas.vim

%files lense-tests
%defattr(-,root,root,-)
%dir %{_datadir}/%{__shrlibname}/%{name}/lenses/dist/tests
%{_datadir}/%{__shrlibname}/%{name}/lenses/dist/tests/*.aug

%changelog
